@@ -9,7 +9,7 @@
 #
 package Dist::Zilla::PluginBundle::RSRCHBOY;
 {
-  $Dist::Zilla::PluginBundle::RSRCHBOY::VERSION = '0.033';
+  $Dist::Zilla::PluginBundle::RSRCHBOY::VERSION = '0.034';
 }
 
 # ABSTRACT: Zilla your distributions like RSRCHBOY!
@@ -42,6 +42,7 @@ use Dist::Zilla::Plugin::ContributorsFromGit        ( );
 use Dist::Zilla::Plugin::CPANFile                   ( );
 use Dist::Zilla::Plugin::EOLTests                   ( );
 use Dist::Zilla::Plugin::ExtraTests                 ( );
+use Dist::Zilla::Plugin::Git::CommitBuild 2.009     ( );
 use Dist::Zilla::Plugin::Git::NextVersion           ( );
 use Dist::Zilla::Plugin::GitHub::Meta               ( );
 use Dist::Zilla::Plugin::GitHub::Update             ( );
@@ -136,16 +137,21 @@ sub release_plugins {
         },
     );
 
-    push @plugins, [ 'GitHub::Update' => { metacpan  => 1 } ]
-        if $self->github;
     push @plugins, 'UploadToCPAN'
         unless $self->is_private;
+    push @plugins, [ 'Git::CommitBuild' => {
+        release_branch       => 'release/cpan',
+        release_message      => 'Full build of CPAN release %v%t',
+        multiple_inheritance => 1,
+    }];
     push @plugins, [ Signature => { sign => 'always' } ]
         if $self->sign;
     push @plugins, [ Twitter => { hash_tags => '#perl #cpan' } ]
         if $self->tweet;
     push @plugins, [ InstallRelease => { install_command => 'cpanm .' } ]
         if $self->install_on_release;
+    push @plugins, [ 'GitHub::Update' => { metacpan  => 1 } ]
+        if $self->github;
 
     push @plugins,
         [ ArchiveRelease   => { directory => 'releases' } ];
@@ -214,6 +220,8 @@ sub configure {
         allow_dirty => [ qw{ cpanfile .gitignore LICENSE dist.ini weaver.ini README.pod Changes } ],
         tag_format  => '%v',
         signed      => $self->sign, # 1,
+        # also push to our fully-built branch
+        push_to     => [ 'origin', 'origin refs/heads/release/cpan:refs/heads/release/cpan' ],
     });
 
     $self->add_plugins([ 'Git::NextVersion' =>
@@ -301,7 +309,7 @@ Dist::Zilla::PluginBundle::RSRCHBOY - Zilla your distributions like RSRCHBOY!
 
 =head1 VERSION
 
-This document describes version 0.033 of Dist::Zilla::PluginBundle::RSRCHBOY - released January 09, 2013 as part of Dist-Zilla-PluginBundle-RSRCHBOY.
+This document describes version 0.034 of Dist::Zilla::PluginBundle::RSRCHBOY - released February 23, 2013 as part of Dist-Zilla-PluginBundle-RSRCHBOY.
 
 =head1 SYNOPSIS
 
